from main import USERHOME
from utils import makedirs
import cPickle

import os


#
# Class for saving the program state of a display. Unlike user configuration,
# program state should not be saved in GConf, since write access to GConf
# keys is not always guaranteed.
#
class StateSaver:

    __STATES_DIR = os.path.join(USERHOME, "states")

    def __init__(self, ident):

        self.__config = {}
        self.__state_file = os.path.join(self.__STATES_DIR, ident)

        if (not os.path.isdir(self.__STATES_DIR)):
            makedirs(self.__STATES_DIR)

        self.__load()


    #
    # Sets the given configuration key.
    #
    def set_key(self, key, value):

        self.__config[key] = value
        self.__save()


    #
    # Retrieves the given configuration key or the given default value if the
    # key does not exist.
    #
    def get_key(self, key, default = None):

        return self.__config.get(key, default)


    #
    # Removes this state.
    #
    def remove(self):

        try:
            os.unlink(self.__state_file)
        except:
            pass
        

    #
    # Loads the configuration from file.
    #
    def __load(self):

        if (os.path.exists(self.__state_file)):
            self.__config = cPickle.load(open(self.__state_file, "rb"))



    #
    # Saves the configuration to file.
    #
    def __save(self):

        cPickle.dump(self.__config, open(self.__state_file, "wb"), True)
